oriole_service.modules package — Oriole-service 4.6.2 documentation

Oriole-service 4.6.2 documentation

# oriole_service.modules package

## Submodules

## oriole_service.modules.conf module

`oriole_service.modules.conf.` `init_parser`(parser)

`oriole_service.modules.conf.` `main`(args)

## oriole_service.modules.doc module

`oriole_service.modules.doc.` `init_parser`(parser)

`oriole_service.modules.doc.` `main`(args)

## oriole_service.modules.halt module

`oriole_service.modules.halt.` `init_parser`(parser)

`oriole_service.modules.halt.` `main`(args)

## oriole_service.modules.run module

`oriole_service.modules.run.` `init_parser`(parser)

`oriole_service.modules.run.` `main`(args)

## oriole_service.modules.sh module

`oriole_service.modules.sh.` `init_parser`(parser)

`oriole_service.modules.sh.` `main`(args)

## oriole_service.modules.test module

`oriole_service.modules.test.` `init_parser`(parser)

`oriole_service.modules.test.` `main`(args)

## Module contents